==> haskell-persistent-2.10.0-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-persistent.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: persistent
version: 2.10.0
id: persistent-2.10.0-F4CPpPaYOvl8cb6reliVex
key: persistent-2.10.0-F4CPpPaYOvl8cb6reliVex
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>
author: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/book/persistent
synopsis: Type-safe, multi-backend data serialization.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/persistent>.
category: Database, Yesod
abi: ec785d7f34241b297b1213d9ea585eff
exposed: True
exposed-modules:
    Database.Persist Database.Persist.Class Database.Persist.Quasi
    Database.Persist.Sql Database.Persist.Sql.Types.Internal
    Database.Persist.Sql.Util Database.Persist.Types
hidden-modules: Database.Persist.Types.Base
                Database.Persist.Class.DeleteCascade
                Database.Persist.Class.PersistEntity
                Database.Persist.Class.PersistQuery
                Database.Persist.Class.PersistUnique
                Database.Persist.Class.PersistConfig
                Database.Persist.Class.PersistField
                Database.Persist.Class.PersistStore Database.Persist.Sql.Migration
                Database.Persist.Sql.Internal Database.Persist.Sql.Types
                Database.Persist.Sql.Raw Database.Persist.Sql.Run
                Database.Persist.Sql.Class Database.Persist.Sql.Orphan.PersistQuery
                Database.Persist.Sql.Orphan.PersistStore
                Database.Persist.Sql.Orphan.PersistUnique
import-dirs: /usr/lib/ghc-8.6.5/site-local/persistent-2.10.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/persistent-2.10.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/persistent-2.10.0
hs-libraries: HSpersistent-2.10.0-F4CPpPaYOvl8cb6reliVex
depends:
    aeson-1.4.4.0-KwovUsQGNt8PPlzoq6sTW
    attoparsec-0.13.2.2-JtccVfLzqCgD0Y1SyaKt8t base-4.12.0.0
    base64-bytestring-1.0.0.2-C0hiEzqCknwIpHHXqmcpJo
    blaze-html-0.9.1.1-Icge9VdFJKdIYmonGkJUKg bytestring-0.10.8.2
    conduit-1.3.1.1-3gq47figCcD3FXjYab6brY containers-0.6.0.1
    fast-logger-2.4.16-IPkSQQPy0a8FH2kw6Cm9rV
    http-api-data-0.4.1-24gDk8mVmZmEhHsrhXyVOb
    monad-logger-0.3.30-4twYlJVifJDLt63DqDQmBG mtl-2.2.2
    path-pieces-0.2.1-7jseLTOU0PkHMQiwNvt0jG
    resource-pool-0.2.3.2-IAoyPiFBos586Bxmdqt9IZ
    resourcet-1.2.2-8hEDHRutAsl8XBsaHNUdIq
    scientific-0.3.6.2-L1dtV0bHm4E7J1We1UVw6b
    silently-1.2.5.1-HV58wYq1AzTJ5xHQM00m1K template-haskell-2.14.0.0
    text-1.2.3.1 time-1.8.0.2 transformers-0.5.6.2
    unliftio-core-0.1.2.0-DmlZdkLzX278vkyONsp8WQ
    unordered-containers-0.2.10.0-1NpUw7eLrexDi5zNhT27CT
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-persistent/html/persistent.haddock
haddock-html: /usr/share/doc/haskell-persistent/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-persistent-2.10.0-3-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-persistent.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: persistent
version: 2.10.0
id: persistent-2.10.0-LM6oLLIdPwCHmJB8aP5byp
key: persistent-2.10.0-LM6oLLIdPwCHmJB8aP5byp
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>
author: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/book/persistent
synopsis: Type-safe, multi-backend data serialization.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/persistent>.
category: Database, Yesod
abi: 0d2429e81a62806e72a0625973732582
exposed: True
exposed-modules:
    Database.Persist Database.Persist.Class Database.Persist.Quasi
    Database.Persist.Sql Database.Persist.Sql.Types.Internal
    Database.Persist.Sql.Util Database.Persist.Types
hidden-modules: Database.Persist.Types.Base
                Database.Persist.Class.DeleteCascade
                Database.Persist.Class.PersistEntity
                Database.Persist.Class.PersistQuery
                Database.Persist.Class.PersistUnique
                Database.Persist.Class.PersistConfig
                Database.Persist.Class.PersistField
                Database.Persist.Class.PersistStore Database.Persist.Sql.Migration
                Database.Persist.Sql.Internal Database.Persist.Sql.Types
                Database.Persist.Sql.Raw Database.Persist.Sql.Run
                Database.Persist.Sql.Class Database.Persist.Sql.Orphan.PersistQuery
                Database.Persist.Sql.Orphan.PersistStore
                Database.Persist.Sql.Orphan.PersistUnique
import-dirs: /usr/lib/ghc-8.6.5/site-local/persistent-2.10.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/persistent-2.10.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/persistent-2.10.0
hs-libraries: HSpersistent-2.10.0-LM6oLLIdPwCHmJB8aP5byp
depends:
    aeson-1.4.4.0-KwovUsQGNt8PPlzoq6sTW
    attoparsec-0.13.2.2-JtccVfLzqCgD0Y1SyaKt8t base-4.12.0.0
    base64-bytestring-1.0.0.2-C0hiEzqCknwIpHHXqmcpJo
    blaze-html-0.9.1.1-Icge9VdFJKdIYmonGkJUKg bytestring-0.10.8.2
    conduit-1.3.1.1-3gq47figCcD3FXjYab6brY containers-0.6.0.1
    fast-logger-2.4.16-40LqQV4hCVlDrT1Ol3Z7b4
    http-api-data-0.4.1-24gDk8mVmZmEhHsrhXyVOb
    monad-logger-0.3.30-f2VRiadyj99WB3NKU59mz mtl-2.2.2
    path-pieces-0.2.1-7jseLTOU0PkHMQiwNvt0jG
    resource-pool-0.2.3.2-IAoyPiFBos586Bxmdqt9IZ
    resourcet-1.2.2-8hEDHRutAsl8XBsaHNUdIq
    scientific-0.3.6.2-L1dtV0bHm4E7J1We1UVw6b
    silently-1.2.5.1-HV58wYq1AzTJ5xHQM00m1K template-haskell-2.14.0.0
    text-1.2.3.1 time-1.8.0.2 transformers-0.5.6.2
    unliftio-core-0.1.2.0-DmlZdkLzX278vkyONsp8WQ
    unordered-containers-0.2.10.0-1NpUw7eLrexDi5zNhT27CT
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-persistent/html/persistent.haddock
haddock-html: /usr/share/doc/haskell-persistent/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
